==> hubzero-cms-1.2.2_1.2.2.8.orig.tar.gz: hubzero-cms-1.2.2-1.2.2.8/cms/components/com_groups/views/media/tmpl/movefolder.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Christopher Smoak <csmoak@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );
?>

<form action="<?php echo JRoute::_('index.php?option=com_groups&cn='.$this->group->get('cn').'&controller=media&task=domovefolder&no_html=1'); ?>" method="post" class="hubForm">
	<fieldset>
		<legend><?php echo JTexT::_('Move Folder'); ?></legend>
		<label>
			<?php echo JText::_('Current Folder: '); ?>
			<input type="text" name="current" value="<?php echo $this->folder; ?>" readonly="readonly" />
		</label>
		<label>
			<?php echo JTexT::_('Move to: '); ?>
			<?php echo $this->folderList; ?>
		</label>
		<p class="controls">
			<button type="submit" class="btn icon-move"><?php echo JTexT::_('Move'); ?></button>
		</p>
	</fieldset>
</form>

==> hubzero-cms-1.3.0_1.3.0.13.orig.tar.gz: hubzero-cms-1.3.0-1.3.0.13/cms/components/com_groups/views/media/tmpl/movefolder.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Christopher Smoak <csmoak@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );
?>

<form action="<?php echo JRoute::_('index.php?option=com_groups&cn='.$this->group->get('cn').'&controller=media&task=domovefolder&no_html=1'); ?>" method="post" class="hubForm">
	<fieldset>
		<legend><?php echo JTexT::_('COM_GROUPS_MEDIA_MOVE_FOLDER'); ?></legend>
		<label>
			<?php echo JText::_('COM_GROUPS_MEDIA_MOVE_CURRENT_FOLDER'); ?>:
			<input type="text" name="current" value="<?php echo $this->folder; ?>" readonly="readonly" />
		</label>
		<label>
			<?php echo JTexT::_('COM_GROUPS_MEDIA_MOVE_MOVE_TO'); ?>:
			<?php echo $this->folderList; ?>
		</label>
		<p class="controls">
			<button type="submit" class="btn icon-move"><?php echo JTexT::_('COM_GROUPS_MEDIA_MOVE'); ?></button>
		</p>
	</fieldset>
</form>
